@@ -1,4 +1,3 @@
-import datetime
 from tkinter import Menu, END, NORMAL, DISABLED
 
 from je_editor import EditorMain
@@ -128,3 +127,6 @@ def start_ite(use_theme=None, debug: bool = False, **kwargs):
         ite_ui.start_editor()
     return ite_ui
 
+
+if __name__ == "__main__":
+    start_ite()
